@@ -153,11 +153,6 @@ struct NautilusCanvasContainerDetails {
 	 */
 	NautilusCanvasIcon *pending_icon_to_reveal;
 
-	/* If a request is made to rename an unpositioned icon we remember
-	 * it and start renaming it once it gets positioned (in relayout).
-	 */
-	NautilusCanvasIcon *pending_icon_to_rename;
-
 	/* Remembered information about the start of the current event. */
 	guint32 button_down_time;
 	
@@ -176,11 +171,6 @@ struct NautilusCanvasContainerDetails {
 
 	NautilusCanvasIcon *range_selection_base_icon;
 	
-	/* Renaming Details */
-	gboolean renaming;
-	GtkWidget *rename_widget;	/* Editable text item */
-	char *original_text;			/* Copy of editable text for later compare */
-
 	/* Idle ID. */
 	guint idle_id;
 
@@ -209,9 +199,6 @@ struct NautilusCanvasContainerDetails {
 	gboolean single_click_mode;
 	gboolean auto_layout;
 
-	/* Label position */
-	NautilusCanvasLabelPosition label_position;
-
 	/* Should the container keep icons aligned to a grid */
 	gboolean keep_aligned;
 
@@ -274,7 +261,6 @@ char *        nautilus_canvas_container_get_icon_drop_target_uri    (NautilusCan
 								       NautilusCanvasIcon          *canvas);
 void          nautilus_canvas_container_update_icon                 (NautilusCanvasContainer *container,
 								       NautilusCanvasIcon          *canvas);
-gboolean      nautilus_canvas_container_has_stored_icon_positions   (NautilusCanvasContainer *container);
 gboolean      nautilus_canvas_container_scroll                      (NautilusCanvasContainer *container,
 								     int                    delta_x,
 								     int                    delta_y);
