@@ -40,8 +40,7 @@
 #include <math.h>
 
 #define OPERATION_MINIMUM_TIME 2 //s
-#define NEEDS_ATTENTION_ANIMATION_TIMEOUT 1000 //ms
-#define NEEDS_ATTENTION_ANIMATION_MULTIPLE_TIMEOUT 3000 //ms
+#define NEEDS_ATTENTION_ANIMATION_TIMEOUT 2000 //ms
 #define REMOVE_FINISHED_OPERATIONS_TIEMOUT 3 //s
 
 typedef enum {
@@ -69,8 +68,6 @@ struct _NautilusToolbarPrivate {
 	GtkWidget *view_button;
 	GtkWidget *action_button;
 
-        guint n_progress_infos_showing;
-
         GtkWidget *operations_popover;
         GtkWidget *operations_container;
         GtkWidget *operations_revealer;
@@ -346,13 +343,40 @@ navigation_button_release_cb (GtkButton *button,
         return FALSE;
 }
 
+static gboolean
+should_show_progress_info (NautilusProgressInfo *info)
+{
+
+        return nautilus_progress_info_get_elapsed_time (info) +
+               nautilus_progress_info_get_remaining_time (info) > OPERATION_MINIMUM_TIME;
+}
+
+static GList*
+get_filtered_progress_infos (NautilusToolbar *self)
+{
+        GList *l;
+        GList *filtered_progress_infos;
+        GList *progress_infos;
+
+        progress_infos = nautilus_progress_info_manager_get_all_infos (self->priv->progress_manager);
+        filtered_progress_infos = NULL;
+
+        for (l = progress_infos; l != NULL; l = l->next) {
+                if (should_show_progress_info (l->data)) {
+                        filtered_progress_infos = g_list_append (filtered_progress_infos, l->data);
+                    }
+        }
+
+        return filtered_progress_infos;
+}
+
 static gboolean
 should_hide_operations_button (NautilusToolbar *self)
 {
         GList *progress_infos;
         GList *l;
 
-        progress_infos = nautilus_progress_info_manager_get_all_infos (self->priv->progress_manager);
+        progress_infos = get_filtered_progress_infos (self);
 
         for (l = progress_infos; l != NULL; l = l->next) {
                 if (nautilus_progress_info_get_elapsed_time (l->data) +
@@ -363,6 +387,8 @@ should_hide_operations_button (NautilusToolbar *self)
                 }
         }
 
+        g_list_free (progress_infos);
+
         return TRUE;
 }
 
@@ -402,19 +428,6 @@ schedule_remove_finished_operations (NautilusToolbar *self)
         }
 }
 
-static gboolean
-remove_operations_button_attention_style_multiple (NautilusToolbar *self)
-{
-        GtkStyleContext *style_context;
-
-        style_context = gtk_widget_get_style_context (self->priv->operations_button);
-        gtk_style_context_remove_class (style_context,
-                                        "nautilus-operations-button-needs-attention-multiple");
-        self->priv->operations_button_attention_timeout_id = 0;
-
-        return G_SOURCE_REMOVE;
-}
-
 static gboolean
 remove_operations_button_attention_style (NautilusToolbar *self)
 {
@@ -436,7 +449,7 @@ add_operations_button_attention_style (NautilusToolbar *self)
         style_context = gtk_widget_get_style_context (self->priv->operations_button);
 
         remove_operations_button_attention_style (self);
-        remove_operations_button_attention_style_multiple (self);
+        remove_operations_button_attention_style (self);
 
         gtk_style_context_add_class (style_context,
                                      "nautilus-operations-button-needs-attention");
@@ -445,31 +458,12 @@ add_operations_button_attention_style (NautilusToolbar *self)
                                                                             self);
 }
 
-static void
-add_operations_button_attention_multiple_style (NautilusToolbar *self)
-{
-        GtkStyleContext *style_context;
-
-        style_context = gtk_widget_get_style_context (self->priv->operations_button);
-
-        remove_operations_button_attention_style (self);
-        remove_operations_button_attention_style_multiple (self);
-
-        gtk_style_context_add_class (style_context,
-                                     "nautilus-operations-button-needs-attention-multiple");
-        self->priv->operations_button_attention_timeout_id = g_timeout_add (NEEDS_ATTENTION_ANIMATION_MULTIPLE_TIMEOUT,
-                                                                            (GSourceFunc) remove_operations_button_attention_style_multiple,
-                                                                            self);
-}
-
 static void
 on_progress_info_cancelled (NautilusToolbar *self)
 {
         /* Update the pie chart progress */
         gtk_widget_queue_draw (self->priv->operations_icon);
 
-        self->priv->n_progress_infos_showing--;
-
         if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->priv->operations_button))) {
                 schedule_remove_finished_operations (self);
         }
@@ -492,8 +486,6 @@ on_progress_info_finished (NautilusToolbar      *self,
         /* Update the pie chart progress */
         gtk_widget_queue_draw (self->priv->operations_icon);
 
-        self->priv->n_progress_infos_showing--;
-
         if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->priv->operations_button))) {
                 schedule_remove_finished_operations (self);
         }
@@ -541,27 +533,24 @@ update_operations (NautilusToolbar *self)
 
         disconnect_progress_infos (self);
 
-        progress_infos = nautilus_progress_info_manager_get_all_infos (self->priv->progress_manager);
-        self->priv->n_progress_infos_showing = 0;
+        progress_infos = get_filtered_progress_infos (self);
         for (l = progress_infos; l != NULL; l = l->next) {
-                if (nautilus_progress_info_get_elapsed_time (l->data) +
-                    nautilus_progress_info_get_remaining_time (l->data) > OPERATION_MINIMUM_TIME) {
-                        total_remaining_time = nautilus_progress_info_get_remaining_time (l->data);
-                        self->priv->n_progress_infos_showing++;
+                total_remaining_time = nautilus_progress_info_get_remaining_time (l->data);
 
-	                g_signal_connect_swapped (l->data, "finished",
-			                          G_CALLBACK (on_progress_info_finished), self);
-	                g_signal_connect_swapped (l->data, "cancelled",
-			                          G_CALLBACK (on_progress_info_cancelled), self);
-	                g_signal_connect_swapped (l->data, "progress-changed",
-			                          G_CALLBACK (on_progress_info_progress_changed), self);
-                        progress = nautilus_progress_info_widget_new (l->data);
-                        gtk_box_pack_start (GTK_BOX (self->priv->operations_container),
-                                            progress,
-                                            FALSE, FALSE, 0);
-                }
+                g_signal_connect_swapped (l->data, "finished",
+		                          G_CALLBACK (on_progress_info_finished), self);
+                g_signal_connect_swapped (l->data, "cancelled",
+		                          G_CALLBACK (on_progress_info_cancelled), self);
+                g_signal_connect_swapped (l->data, "progress-changed",
+		                          G_CALLBACK (on_progress_info_progress_changed), self);
+                progress = nautilus_progress_info_widget_new (l->data);
+                gtk_box_pack_start (GTK_BOX (self->priv->operations_container),
+                                    progress,
+                                    FALSE, FALSE, 0);
         }
 
+        g_list_free (progress_infos);
+
         /* Either we are already showing the button, so keep showing it until the user
          * toggle it to hide the operations popover, or, if we want now to show it,
          * we have to have at least one operation that its total stimated time
@@ -573,7 +562,7 @@ update_operations (NautilusToolbar *self)
          */
         if (total_remaining_time > OPERATION_MINIMUM_TIME &&
             !gtk_revealer_get_reveal_child (GTK_REVEALER (self->priv->operations_revealer))) {
-                add_operations_button_attention_multiple_style (self);
+                add_operations_button_attention_style (self);
                 gtk_revealer_set_reveal_child (GTK_REVEALER (self->priv->operations_revealer),
                                                TRUE);
                 gtk_widget_queue_draw (self->priv->operations_icon);
@@ -584,20 +573,25 @@ static gboolean
 on_progress_info_started_timeout (NautilusToolbar *self)
 {
         GList *progress_infos;
+        GList *filtered_progress_infos;
 
         update_operations (self);
 
         /* In case we didn't show the operations button because the operation total
          * time stimation is not good enough, update again to make sure we don't miss
          * a long time operation because of that */
+
         progress_infos = nautilus_progress_info_manager_get_all_infos (self->priv->progress_manager);
+        filtered_progress_infos = get_filtered_progress_infos (self);
         if (!nautilus_progress_manager_are_all_infos_finished_or_cancelled (self->priv->progress_manager) &&
-            g_list_length (progress_infos) != self->priv->n_progress_infos_showing) {
+            g_list_length (progress_infos) != g_list_length (filtered_progress_infos)) {
                 return G_SOURCE_CONTINUE;
         } else {
                 self->priv->start_operations_timeout_id = 0;
                 return G_SOURCE_REMOVE;
         }
+
+        g_list_free (filtered_progress_infos);
 }
 
 static void
@@ -657,7 +651,7 @@ on_operations_icon_draw (GtkWidget       *widget,
         GdkRGBA foreground = {.red = 0, .green = 0, .blue = 0, .alpha = 0.7 };
 
         all_cancelled = TRUE;
-        progress_infos = nautilus_progress_info_manager_get_all_infos (self->priv->progress_manager);
+        progress_infos = get_filtered_progress_infos (self);
         for (l = progress_infos; l != NULL; l = l->next) {
                 if (!nautilus_progress_info_get_is_cancelled (l->data)) {
                         all_cancelled = FALSE;
@@ -666,6 +660,8 @@ on_operations_icon_draw (GtkWidget       *widget,
                 }
         }
 
+        g_list_free (progress_infos);
+
         total_progress = remaining_progress + elapsed_progress;
 
         if (all_cancelled) {
