@@ -110,6 +110,7 @@ struct _NautilusWindowPrivate {
         GtkWidget *sidebar;        /* container for the GtkPlacesSidebar */
         GtkWidget *places_sidebar; /* the actual GtkPlacesSidebar */
         GVolume *selected_volume; /* the selected volume in the sidebar popup callback */
+        GFile *selected_file; /* the selected file in the sidebar popup callback */
 
         /* Main view */
         GtkWidget *main_view;
@@ -1066,17 +1067,16 @@ action_properties (GSimpleAction *action,
                    gpointer       user_data)
 {
 	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
-	GFile *selected;
 	GList *list;
 	NautilusFile *file;
 
-	selected = gtk_places_sidebar_get_location (GTK_PLACES_SIDEBAR (window->priv->places_sidebar));
-	file = nautilus_file_get (selected);
-	g_object_unref (selected);
+	file = nautilus_file_get (window->priv->selected_file);
 
 	list = g_list_append (NULL, file);
 	nautilus_properties_window_present (list, GTK_WIDGET (window), NULL);
 	nautilus_file_list_free (list);
+
+	g_clear_object (&window->priv->selected_file);
 }
 
 static gboolean
@@ -1150,7 +1150,7 @@ add_menu_separator (GtkWidget *menu)
 static void
 places_sidebar_populate_popup_cb (GtkPlacesSidebar *sidebar,
 				  GtkWidget        *menu,
-				  GFile            *selected_item,
+				  GFile            *selected_file,
 				  GVolume          *selected_volume,
 				  gpointer          user_data)
 {
@@ -1159,9 +1159,12 @@ places_sidebar_populate_popup_cb (GtkPlacesSidebar *sidebar,
         GtkWidget *menu_item;
         GAction *action;
 
-	if (selected_item) {
+	g_clear_object (&window->priv->selected_file);
+	g_clear_object (&window->priv->selected_volume);
+
+	if (selected_file) {
 		trash = g_file_new_for_uri ("trash:///");
-		if (g_file_equal (trash, selected_item)) {
+		if (g_file_equal (trash, selected_file)) {
                         add_menu_separator (menu);
 
                         menu_item = gtk_model_button_new ();
@@ -1178,7 +1181,8 @@ places_sidebar_populate_popup_cb (GtkPlacesSidebar *sidebar,
 		}
 		g_object_unref (trash);
 
-		if (g_file_is_native (selected_item)) {
+		if (g_file_is_native (selected_file)) {
+                        window->priv->selected_file = g_object_ref (selected_file);
                         add_menu_separator (menu);
 
                         menu_item = gtk_model_button_new ();
@@ -2120,6 +2124,9 @@ nautilus_window_finalize (GObject *object)
                 window->priv->notification_operation_timeout_id = 0;
 	}
 
+	g_clear_object (&window->priv->selected_file);
+	g_clear_object (&window->priv->selected_volume);
+
 	g_signal_handlers_disconnect_by_func (nautilus_file_undo_manager_get (),
                                               G_CALLBACK (nautilus_window_on_undo_changed),
                                               window);
